Class: Google::Apis::MerchantapiPromotionsV1beta::ItemLevelIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_promotions_v1beta/classes.rb,
lib/google/apis/merchantapi_promotions_v1beta/representations.rb,
lib/google/apis/merchantapi_promotions_v1beta/representations.rb

Overview

The issue associated with the promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ItemLevelIssue

Returns a new instance of ItemLevelIssue.



560
561
562
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applicable_countriesArray<String>

Output only. List of country codes (ISO 3166-1 alpha-2) where issue applies to the offer. Corresponds to the JSON property applicableCountries

Returns:

  • (Array<String>)


517
518
519
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 517

def applicable_countries
  @applicable_countries
end

#attributeString

Output only. The attribute's name, if the issue is caused by a single attribute. Corresponds to the JSON property attribute

Returns:

  • (String)


523
524
525
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 523

def attribute
  @attribute
end

#codeString

Output only. The error code of the issue. Corresponds to the JSON property code

Returns:

  • (String)


528
529
530
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 528

def code
  @code
end

#descriptionString

Output only. A short issue description in English. Corresponds to the JSON property description

Returns:

  • (String)


533
534
535
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 533

def description
  @description
end

#detailString

Output only. A detailed issue description in English. Corresponds to the JSON property detail

Returns:

  • (String)


538
539
540
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 538

def detail
  @detail
end

#documentationString

Output only. The URL of a web page to help with resolving this issue. Corresponds to the JSON property documentation

Returns:

  • (String)


543
544
545
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 543

def documentation
  @documentation
end

#reporting_contextString

Output only. The destination the issue applies to. Corresponds to the JSON property reportingContext

Returns:

  • (String)


548
549
550
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 548

def reporting_context
  @reporting_context
end

#resolutionString

Output only. Whether the issue can be resolved by the merchant. Corresponds to the JSON property resolution

Returns:

  • (String)


553
554
555
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 553

def resolution
  @resolution
end

#severityString

Output only. How this issue affects serving of the promotion. Corresponds to the JSON property severity

Returns:

  • (String)


558
559
560
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 558

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



565
566
567
568
569
570
571
572
573
574
575
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 565

def update!(**args)
  @applicable_countries = args[:applicable_countries] if args.key?(:applicable_countries)
  @attribute = args[:attribute] if args.key?(:attribute)
  @code = args[:code] if args.key?(:code)
  @description = args[:description] if args.key?(:description)
  @detail = args[:detail] if args.key?(:detail)
  @documentation = args[:documentation] if args.key?(:documentation)
  @reporting_context = args[:reporting_context] if args.key?(:reporting_context)
  @resolution = args[:resolution] if args.key?(:resolution)
  @severity = args[:severity] if args.key?(:severity)
end