Class: Google::Apis::MerchantapiPromotionsV1beta::MerchantService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::MerchantapiPromotionsV1beta::MerchantService
- Defined in:
- lib/google/apis/merchantapi_promotions_v1beta/service.rb
Overview
Merchant API
Programmatically manage your Merchant Center Accounts.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://merchantapi.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#get_account_promotion(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiPromotionsV1beta::Promotion
Retrieves the promotion from your Merchant Center account.
-
#initialize ⇒ MerchantService
constructor
A new instance of MerchantService.
-
#insert_promotion(parent, insert_promotion_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiPromotionsV1beta::Promotion
Inserts a promotion for your Merchant Center account.
-
#list_account_promotions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiPromotionsV1beta::ListPromotionsResponse
Lists the promotions in your Merchant Center account.
Constructor Details
#initialize ⇒ MerchantService
Returns a new instance of MerchantService.
47 48 49 50 51 52 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-merchantapi_promotions_v1beta', client_version: Google::Apis::MerchantapiPromotionsV1beta::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#get_account_promotion(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiPromotionsV1beta::Promotion
Retrieves the promotion from your Merchant Center account. After inserting or updating a promotion input, it may take several minutes before the updated promotion can be retrieved.
77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/service.rb', line 77 def get_account_promotion(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'promotions/v1beta/{+name}', ) command.response_representation = Google::Apis::MerchantapiPromotionsV1beta::Promotion::Representation command.response_class = Google::Apis::MerchantapiPromotionsV1beta::Promotion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#insert_promotion(parent, insert_promotion_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiPromotionsV1beta::Promotion
Inserts a promotion for your Merchant Center account. If the promotion already exists, then it updates the promotion instead.
110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/service.rb', line 110 def insert_promotion(parent, insert_promotion_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'promotions/v1beta/{+parent}/promotions:insert', ) command.request_representation = Google::Apis::MerchantapiPromotionsV1beta::InsertPromotionRequest::Representation command.request_object = insert_promotion_request_object command.response_representation = Google::Apis::MerchantapiPromotionsV1beta::Promotion::Representation command.response_class = Google::Apis::MerchantapiPromotionsV1beta::Promotion command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_account_promotions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiPromotionsV1beta::ListPromotionsResponse
Lists the promotions in your Merchant Center account. The response might
contain fewer items than specified by pageSize. Rely on pageToken to
determine if there are more items to be requested. After inserting or updating
a promotion, it may take several minutes before the updated processed
promotion can be retrieved.
157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/service.rb', line 157 def list_account_promotions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'promotions/v1beta/{+parent}/promotions', ) command.response_representation = Google::Apis::MerchantapiPromotionsV1beta::ListPromotionsResponse::Representation command.response_class = Google::Apis::MerchantapiPromotionsV1beta::ListPromotionsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |