Class: Google::Apis::MerchantapiPromotionsV1beta::PromotionStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_promotions_v1beta/classes.rb,
lib/google/apis/merchantapi_promotions_v1beta/representations.rb,
lib/google/apis/merchantapi_promotions_v1beta/representations.rb

Overview

The status of the promotion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PromotionStatus

Returns a new instance of PromotionStatus.



882
883
884
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_dateString

Output only. Date on which the promotion has been created in ISO 8601 format: Date, time, and offset, for example 2020-01-02T09:00:00+01:00 or 2020-01-02T09:00:00Z Corresponds to the JSON property creationDate

Returns:

  • (String)


863
864
865
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 863

def creation_date
  @creation_date
end

#destination_statusesArray<Google::Apis::MerchantapiPromotionsV1beta::DestinationStatus>

Output only. The intended destinations for the promotion. Corresponds to the JSON property destinationStatuses



868
869
870
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 868

def destination_statuses
  @destination_statuses
end

#item_level_issuesArray<Google::Apis::MerchantapiPromotionsV1beta::ItemLevelIssue>

Output only. A list of issues associated with the promotion. Corresponds to the JSON property itemLevelIssues



873
874
875
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 873

def item_level_issues
  @item_level_issues
end

#last_update_dateString

Output only. Date on which the promotion status has been last updated in ISO 8601 format: Date, time, and offset, for example 2020-01-02T09:00:00+01:00 or 2020-01-02T09:00:00Z Corresponds to the JSON property lastUpdateDate

Returns:

  • (String)


880
881
882
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 880

def last_update_date
  @last_update_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



887
888
889
890
891
892
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 887

def update!(**args)
  @creation_date = args[:creation_date] if args.key?(:creation_date)
  @destination_statuses = args[:destination_statuses] if args.key?(:destination_statuses)
  @item_level_issues = args[:item_level_issues] if args.key?(:item_level_issues)
  @last_update_date = args[:last_update_date] if args.key?(:last_update_date)
end