Class: Google::Apis::MerchantapiPromotionsV1beta::ItemLevelIssue
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiPromotionsV1beta::ItemLevelIssue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_promotions_v1beta/classes.rb,
lib/google/apis/merchantapi_promotions_v1beta/representations.rb,
lib/google/apis/merchantapi_promotions_v1beta/representations.rb
Overview
The issue associated with the promotion.
Instance Attribute Summary collapse
-
#applicable_countries ⇒ Array<String>
Output only.
-
#attribute ⇒ String
Output only.
-
#code ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#detail ⇒ String
Output only.
-
#documentation ⇒ String
Output only.
-
#reporting_context ⇒ String
Output only.
-
#resolution ⇒ String
Output only.
-
#severity ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ItemLevelIssue
constructor
A new instance of ItemLevelIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ItemLevelIssue
Returns a new instance of ItemLevelIssue.
560 561 562 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 560 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applicable_countries ⇒ Array<String>
Output only. List of country codes (ISO 3166-1 alpha-2) where issue applies to
the offer.
Corresponds to the JSON property applicableCountries
517 518 519 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 517 def applicable_countries @applicable_countries end |
#attribute ⇒ String
Output only. The attribute's name, if the issue is caused by a single
attribute.
Corresponds to the JSON property attribute
523 524 525 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 523 def attribute @attribute end |
#code ⇒ String
Output only. The error code of the issue.
Corresponds to the JSON property code
528 529 530 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 528 def code @code end |
#description ⇒ String
Output only. A short issue description in English.
Corresponds to the JSON property description
533 534 535 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 533 def description @description end |
#detail ⇒ String
Output only. A detailed issue description in English.
Corresponds to the JSON property detail
538 539 540 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 538 def detail @detail end |
#documentation ⇒ String
Output only. The URL of a web page to help with resolving this issue.
Corresponds to the JSON property documentation
543 544 545 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 543 def documentation @documentation end |
#reporting_context ⇒ String
Output only. The destination the issue applies to.
Corresponds to the JSON property reportingContext
548 549 550 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 548 def reporting_context @reporting_context end |
#resolution ⇒ String
Output only. Whether the issue can be resolved by the merchant.
Corresponds to the JSON property resolution
553 554 555 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 553 def resolution @resolution end |
#severity ⇒ String
Output only. How this issue affects serving of the promotion.
Corresponds to the JSON property severity
558 559 560 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 558 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
565 566 567 568 569 570 571 572 573 574 575 |
# File 'lib/google/apis/merchantapi_promotions_v1beta/classes.rb', line 565 def update!(**args) @applicable_countries = args[:applicable_countries] if args.key?(:applicable_countries) @attribute = args[:attribute] if args.key?(:attribute) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) @detail = args[:detail] if args.key?(:detail) @documentation = args[:documentation] if args.key?(:documentation) @reporting_context = args[:reporting_context] if args.key?(:reporting_context) @resolution = args[:resolution] if args.key?(:resolution) @severity = args[:severity] if args.key?(:severity) end |